@@ -9,13 +9,14 @@ extern FIELD fields[7];
 extern int ingame, playing, paused;
 extern int moderator, spectating;
 extern int bigfieldnum;
+extern int gmsgstate;
 
 extern char specialblocks[256];
 extern int specialblocknum;
 
 extern void tetrinet_inmessage (enum inmsg_type msgtype, char *data);
-extern void tetrinet_playerline (char *text);
-extern void tetrinet_changeteam (char *newteam);
+extern void tetrinet_playerline (const char *text);
+extern void tetrinet_changeteam (const char *newteam);
 extern void tetrinet_updatefield (FIELD field);
 extern void tetrinet_sendfield (int reset);
 extern void tetrinet_resendfield (void);
@@ -30,3 +31,5 @@ extern void tetrinet_playerlost (void);
 extern void tetrinet_endgame (void);
 
 extern int playerfield (int p);
+
+extern void fieldslabelupdate (void);
